@@ -1,10 +1,13 @@
-import json
+import os
 import re
 import sys
 import copy
+import json
+import yaml
 import urllib
 import logging
 import dateutil.parser
+
 from prettytable import PrettyTable, PLAIN_COLUMNS
 from collections import OrderedDict
 #from textwrap import fill
@@ -13,6 +16,97 @@ import anchorecli.clients.apiexternal
 
 _logger = logging.getLogger(__name__)
 
+def setup_config(cli_opts):
+    ret = {
+        'user':None,
+        'pass':None,
+        'url':"http://localhost:8228/v1",
+        'ssl_verify':True,
+        'jsonmode':False,
+        'debug':False,
+    }
+
+    settings = {}
+
+    # load up credentials file if present
+    try:
+        home = os.environ.get('HOME', None)
+        credential_file = os.path.join(home, '.anchore', 'credentials.yaml')
+        if os.path.exists(credential_file):
+            ydata = {}
+            with open(credential_file, 'r') as FH:
+                try:
+                    ydata = yaml.safe_load(FH)
+                except Exception as err:
+                    raise Exception("YAML load failed: " + str(err))
+            if ydata:
+                try:
+                    if type(ydata) != type(dict()):
+                        raise Exception("invalid credentials file format")
+
+                    default_creds = ydata.get('default', {})
+                    for e in ['ANCHORE_CLI_USER', 'ANCHORE_CLI_PASS', 'ANCHORE_CLI_URL', 'ANCHORE_CLI_SSL_VERIFY']:
+                        if e in default_creds:
+                            settings[e] = default_creds[e]
+                except Exception as err:
+                    raise Exception("credentials file exists and has data, but cannot parse: " + str(err))
+
+    except Exception as err:
+        raise Exception("error while processing credentials file, please check format and read permissions - exception: " + str(err))
+    
+    # load environment if present
+    try:
+        for e in ['ANCHORE_CLI_USER', 'ANCHORE_CLI_PASS', 'ANCHORE_CLI_URL', 'ANCHORE_CLI_SSL_VERIFY', 'ANCHORE_CLI_JSON', 'ANCHORE_CLI_DEBUG']:
+            if e in os.environ:
+                settings[e] = os.environ[e]
+    except Exception as err:
+        raise err
+
+    # load cmdline options
+    try:
+        if cli_opts['u']:
+            settings['ANCHORE_CLI_USER'] = cli_opts['u']
+
+        if cli_opts['p']:
+            settings['ANCHORE_CLI_PASS'] = cli_opts['p']
+
+        if cli_opts['url']:
+            settings['ANCHORE_CLI_URL'] = cli_opts['url']
+
+        if cli_opts['insecure']:
+            settings['ANCHORE_CLI_SSL_VERIFY'] = "n"
+
+        if cli_opts['json']:
+            settings['ANCHORE_CLI_JSON'] = "y"
+        
+        if cli_opts['debug']:
+            settings['ANCHORE_CLI_DEBUG'] = "y"
+
+    except Exception as err:
+        raise err
+
+    try:
+        if 'ANCHORE_CLI_USER' in settings:
+            ret['user'] = settings['ANCHORE_CLI_USER']
+        if 'ANCHORE_CLI_PASS' in settings:
+            ret['pass'] = settings['ANCHORE_CLI_PASS']
+        if 'ANCHORE_CLI_URL' in settings:
+            ret['url'] = settings['ANCHORE_CLI_URL']
+
+        if 'ANCHORE_CLI_SSL_VERIFY' in settings:
+            if settings['ANCHORE_CLI_SSL_VERIFY'].lower() == 'n':
+                ret['ssl_verify'] = False
+        if 'ANCHORE_CLI_JSON' in settings:
+            if settings['ANCHORE_CLI_JSON'].lower() == 'y':
+                ret['jsonmode'] = True
+        if 'ANCHORE_CLI_DEBUG' in settings:
+            if settings['ANCHORE_CLI_DEBUG'].lower() == 'y':
+                ret['debug'] = True
+    except Exception as err:
+        raise err
+
+    return(ret)
+
 def doexit(ecode):
     try:
         sys.stdout.close()
@@ -208,7 +302,7 @@ def format_output(config, op, params, payload):
                         row = [el['filename'], el['size']]
                         t.add_row(row)
                     obuf = obuf + t.get_string(sortby='Size', reversesort=True)
-                elif params['query_type'] in ['npm', 'gem']:
+                elif params['query_type'] in ['npm', 'gem', 'python']:
                     header = ['Package', 'Version', 'Location']
                     t = PrettyTable(header)
                     t.set_style(PLAIN_COLUMNS)
@@ -217,6 +311,15 @@ def format_output(config, op, params, payload):
                         row = [el['package'], el['version'], el['location']]
                         t.add_row(row)
                     obuf = obuf + t.get_string(sortby='Package')
+                elif params['query_type'] in ['java']:
+                    header = ['Package', 'Specification-Version', 'Implementation-Version', 'Location']
+                    t = PrettyTable(header)
+                    t.set_style(PLAIN_COLUMNS)
+                    t.align = 'l'
+                    for el in payload['content']:
+                        row = [el['package'], el['specification-version'], el['implementation-version'], el['location']]
+                        t.add_row(row)
+                    obuf = obuf + t.get_string(sortby='Package')
                 else:
                     try:
                         if payload['content']:
@@ -254,8 +357,19 @@ def format_output(config, op, params, payload):
                     dockerpresent = "Present"
 
                 imageId = image_detail.pop('imageId', "None") 
-                outdict['Dockerfile'] = str(dockerpresent)
                 outdict['Image ID'] = str(imageId)
+                #outdict['Dockerfile'] = str(dockerpresent)
+
+                if 'image_content' in image_record and image_record['image_content']:
+                    image_content = image_record['image_content']
+                    if 'metadata' in image_content and image_content['metadata']:
+                        image_content_metadata = image_content['metadata']
+                        outdict['Dockerfile Mode'] = str(image_content_metadata['dockerfile_mode'])
+                        outdict['Distro'] = str(image_content_metadata['distro'])
+                        outdict['Distro Version'] = str(image_content_metadata['distro_version'])
+                        outdict['Size'] = str(image_content_metadata['image_size'])
+                        outdict['Architecture'] = str(image_content_metadata['arch'])
+                        outdict['Layer Count'] = str(image_content_metadata['layer_count'])
 
                 for k in outdict.keys():
                     obuf = obuf + k + ": " + outdict[k] + "\n"
